==> jc-train-cuizheng2-client-2.0.170-sources.jar: com/xforceplus/jctraincuizheng2/controller/AutotestfudianxingFeignApi.java <==
package com.xforceplus.jctraincuizheng2.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-09-28
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jctraincuizheng2.entity.Autotestfudianxing;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-train-cuizheng2")
public interface AutotestfudianxingFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/autotestfudianxing/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param autotestfudianxing ${table.comment}
   * @return R
   */
  @PostMapping("/autotestfudianxing/add")
  public R save(@RequestBody Autotestfudianxing autotestfudianxing);

  /**
   * 修改${table.comment}
   * @param autotestfudianxing ${table.comment}
   * @return R
   */
  @PostMapping("/autotestfudianxing/update")
  public R updateById(@RequestBody Autotestfudianxing autotestfudianxing);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/autotestfudianxing/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-train-cuizheng2-client-2.0.277-sources.jar: com/xforceplus/jctraincuizheng2/controller/AutotestfudianxingFeignApi.java <==
package com.xforceplus.jctraincuizheng2.controller;


/**
 * autotestfudianxingfeign客户端
 *
 * @author ultraman
 * @date 2021-11-05
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jctraincuizheng2.entity.Autotestfudianxing;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-train-cuizheng2")
public interface AutotestfudianxingFeignApi {

  /**
   * 通过id查询autotestfudianxing
   * @param  id
   * @return R
   */
  @GetMapping("/autotestfudianxing/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增autotestfudianxing
   * @param autotestfudianxing autotestfudianxing
   * @return R
   */
  @PostMapping("/autotestfudianxing/add")
  public R save(@RequestBody Autotestfudianxing autotestfudianxing);

  /**
   * 修改autotestfudianxing
   * @param autotestfudianxing autotestfudianxing
   * @return R
   */
  @PostMapping("/autotestfudianxing/update")
  public R updateById(@RequestBody Autotestfudianxing autotestfudianxing);

  /**
   * 通过id删除autotestfudianxing
   * @param  id
   * @return R
   */
  @DeleteMapping("/autotestfudianxing/del/{id}" )
  public R removeById(@PathVariable Long id);

}
